==> quanyi-center-api-1.3.34-act-20250430.055946-4-sources.jar: cn/com/duiba/quanyi/center/api/enums/activity/common/ActivityPeriodicUnitEnum.java <==
package cn.com.duiba.quanyi.center.api.enums.activity.common;

import cn.hutool.core.date.DateUtil;
import lombok.AllArgsConstructor;
import lombok.Getter;
import org.apache.commons.lang3.tuple.Pair;

import java.util.Arrays;
import java.util.Collections;
import java.util.Date;
import java.util.Map;
import java.util.function.Function;
import java.util.stream.Collectors;

/**
 * @author lizhi
 * @date 2025/4/22 14:00
 */
@AllArgsConstructor
@Getter
public enum ActivityPeriodicUnitEnum {
    FOREVER(1, "永久"),
    ABSOLUTE(2, "绝对时间"),
    DAY(3, "日"),
    WEEK(4, "自然周"),
    MONTH(5, "自然月"),
    QUARTER(6,"季度"),
    ;
    
    private final Integer code;
    
    private final String desc;
    
    public Pair<Date, Date> getDate(Date now, Date absoluteStartTime, Date absoluteEndTime) {
        switch (this) {
            case FOREVER:
                return Pair.of(null, null);
            case ABSOLUTE:
                return Pair.of(absoluteStartTime, absoluteEndTime);
            case DAY:
                return Pair.of(DateUtil.beginOfDay(now), DateUtil.endOfDay(now));
            case WEEK:
                return Pair.of(DateUtil.beginOfWeek(now), DateUtil.endOfWeek(now));
            case MONTH:
                return Pair.of(DateUtil.beginOfMonth(now), DateUtil.endOfMonth(now));
            case QUARTER:
                return Pair.of(DateUtil.beginOfQuarter(now), DateUtil.endOfQuarter(now));
            default:
                return null;
        }
    }
    
    private static final Map<Integer, ActivityPeriodicUnitEnum> ENUM_MAP = Collections.unmodifiableMap(Arrays.stream(values()).collect(Collectors.toMap(ActivityPeriodicUnitEnum::getCode, Function.identity(), (v1, v2) -> v2)));
    
    /**
     * 根据枚举值获取枚举
     * @param code 枚举值
     * @return 枚举
     */
    public static ActivityPeriodicUnitEnum getByCode(Integer code) {
        if (code == null) {
            return null;
        }
        return ENUM_MAP.get(code);
    }
}

==> quanyi-center-api-1.3.36-act-20250514.083039-8-sources.jar: cn/com/duiba/quanyi/center/api/enums/activity/common/ActivityPeriodicUnitEnum.java <==
package cn.com.duiba.quanyi.center.api.enums.activity.common;

import cn.hutool.core.date.DateUtil;
import lombok.AllArgsConstructor;
import lombok.Getter;
import org.apache.commons.lang3.tuple.Pair;
import org.apache.commons.lang3.tuple.Triple;

import java.util.Arrays;
import java.util.Collections;
import java.util.Date;
import java.util.List;
import java.util.Map;
import java.util.function.Function;
import java.util.stream.Collectors;

/**
 * @author lizhi
 * @date 2025/4/22 14:00
 */
@AllArgsConstructor
@Getter
public enum ActivityPeriodicUnitEnum {
    FOREVER(1, "永久"),
    ABSOLUTE(2, "绝对时间"),
    DAY(3, "日"),
    WEEK(4, "自然周"),
    MONTH(5, "自然月"),
    QUARTER(6,"季度"),
    ;
    
    private final Integer code;
    
    private final String desc;
    
    /**
     * 获取当前周期范围
     * @param now
     * @param absoluteStartTime
     * @param absoluteEndTime
     * @return
     */
    public Pair<Date, Date> getDate(Date now, Date absoluteStartTime, Date absoluteEndTime) {
        switch (this) {
            case FOREVER:
                return Pair.of(null, null);
            case ABSOLUTE:
                return Pair.of(absoluteStartTime, absoluteEndTime);
            case DAY:
                return Pair.of(DateUtil.beginOfDay(now), DateUtil.endOfDay(now));
            case WEEK:
                return Pair.of(DateUtil.beginOfWeek(now), DateUtil.endOfWeek(now));
            case MONTH:
                return Pair.of(DateUtil.beginOfMonth(now), DateUtil.endOfMonth(now));
            case QUARTER:
                return Pair.of(DateUtil.beginOfQuarter(now), DateUtil.endOfQuarter(now));
            default:
                return null;
        }
    }
    
    /**
     * 获取当前期次值
     * @return
     */
    public Pair<Date, Date> getCurrentPeriod() {
        return getDate(new Date(), null, null);
    }

    /**
     * 获取期次值
     * @param offset
     * @return
     */
    public Pair<Date, Date> getOffsetPeriod(int offset) {
        Date now = new Date();
        switch (this) {
            case DAY:
                now = DateUtil.offsetDay(now, offset);
                break;
            case WEEK:
                now = DateUtil.offsetWeek(now, offset);
                break;
            case MONTH:
                now = DateUtil.offsetMonth(now, offset);
                break;
            case QUARTER:
                now = DateUtil.offsetMonth(now, offset * 3);
                break;
            default:
        }
        return getDate(now, null, null);
    }

    /**
     * 获取期次发放枚举集合
     * @return
     */
    public static List<ActivityPeriodicUnitEnum> getPeriodTakeEnums(){
        return Arrays.asList(ActivityPeriodicUnitEnum.DAY, ActivityPeriodicUnitEnum.WEEK, ActivityPeriodicUnitEnum.MONTH, ActivityPeriodicUnitEnum.QUARTER);
    }

    private static final Map<Integer, ActivityPeriodicUnitEnum> ENUM_MAP = Collections.unmodifiableMap(Arrays.stream(values()).collect(Collectors.toMap(ActivityPeriodicUnitEnum::getCode, Function.identity(), (v1, v2) -> v2)));
    
    /**
     * 根据枚举值获取枚举
     * @param code 枚举值
     * @return 枚举
     */
    public static ActivityPeriodicUnitEnum getByCode(Integer code) {
        if (code == null) {
            return null;
        }
        return ENUM_MAP.get(code);
    }
}
